==> Southxchange-1.0.tar.gz: Southxchange-1.0/README.md <==
# [Southxchange](www.southxchange.com/)

<img src='data:image/png;base64,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'>


[Donate Bitcoin](https://paywall.link/to/donate)

Southxchange is a cryptocurrency broker that does not require KYC trading is accepted with Lightning, with this library you can interact with the platform.

#### Market
 - [x] List Orders
 - [x] Place Order
 - [x] Cancel Order
 - [x] Cancel Orders

#### Wallets
 - [x] Generate Address
 - [ ] Withdraw
 - [x] Balances
 - [x] Transactions List.
 
## Instalation

##### (Southxchange)  requires [ Python ](https://www.python.org) v3.8

```sh
$ pip install Southxchange
```

#### Getting Started

```python
Python 3.8.3 (default, Jun 16 2020, 19:00:28)
[GCC 6.3.0 20170516] on linux
Type "help", "copyright", "credits" or "license" for more information.
>>>
>>> import Southxchange
>>> 
>>> Southxchange.Southxchange('Private', 'Secret') # Entering credentials.
>>> 
```

#### Market

```python
>>> Market = Southxchange.Market()
>>> 
>>> Market.placeorder('DOGE', 'BTC', amount=1, type='BUY', limitprice='0.00000001') # Place Order.
{'error' : False, 'message' : 'Created order.', 'orderid' : 123456}
>>> 
>>> Market.cancelorder(123456) # Cancel Order.
{'error' : False, 'message' : 'Cancel order.', 'orderid' : 123456}
>>>
>>> Market.cancelorders('BTC', 'DOGE') # Cancel Orders
{'error' : False, 'message' : 'Cancel orders.'}
>>>
>>> Market.listorders() # List Orders.
[{'Code': '132541', 'Type': 'buy', 'Amount': 1.0, 'OriginalAmount': 1.0, 'LimitPrice': 1e-08, 'ListingCurrency': 'DOGE', 'ReferenceCurrency': 'BTC'}]
>>>
```

#### Wallets

```python
>>> Wallets = Southxchange.Wallets()
>>> 
>>> Wallets.newaddress('BTC') # New Address.
{'error': False, 'message': 'New address generated.', 'address': '3G983JSIM ...'}
>>>
>>> Wallets.balances() # List Balances.
[{"Currency":"BTC","Deposited": 1 ,"Available": 1, "Unconfirmed": 5}]
>>>
>>> Wallets.transactions('BTC', type='transactions', pageindex=1, pagesize=50) # List History Transactions.
{'TotalElements': 50, 'Result': [{...} ...] ...}
```

==> Southxchange-1.1.tar.gz: Southxchange-1.1/README.md <==
# [Southxchange](www.southxchange.com/)

[Donate Bitcoin](https://paywall.link/to/donate)

Southxchange is a cryptocurrency broker that does not require KYC trading is accepted with Lightning, with this library you can interact with the platform.

#### Market
 - [x] List Orders
 - [x] Place Order
 - [x] Cancel Order
 - [x] Cancel Orders

#### Wallets
 - [x] Generate Address
 - [x] Withdraw
 - [x] Balances
 - [x] Transactions List

## Instalation

##### (Southxchange)  requires [ Python ](https://www.python.org) v3.8

```sh
$ pip install Southxchange
```

#### Getting Started

```python
Python 3.8.3 (default, Jun 16 2020, 19:00:28)
[GCC 6.3.0 20170516] on linux
Type "help", "copyright", "credits" or "license" for more information.
>>>
>>> import Southxchange
>>>
>>> Southxchange.Southxchange('Private', 'Secret') # Entering credentials.
>>>
```

#### Market

```python
>>> Market = Southxchange.Market()
>>>
>>> Market.placeorder('DOGE', 'BTC', amount=1, type='BUY', limitprice='0.00000001') # Place Order.
{'error' : False, 'message' : 'Created order.', 'orderid' : 123456}
>>>
>>> Market.cancelorder(123456) # Cancel Order.
{'error' : False, 'message' : 'Cancel order.', 'orderid' : 123456}
>>>
>>> Market.cancelorders('BTC', 'DOGE') # Cancel Orders
{'error' : False, 'message' : 'Cancel orders.'}
>>>
>>> Market.listorders() # List Orders.
[{'Code': '132541', 'Type': 'buy', 'Amount': 1.0, 'OriginalAmount': 1.0, 'LimitPrice': 1e-08, 'ListingCurrency': 'DOGE', 'ReferenceCurrency': 'BTC'}]
>>>
```

#### Wallets

```python
>>> Wallets = Southxchange.Wallets()
>>>
>>> Wallets.newaddress('BTC') # New Address.
{'error': False, 'message': 'New address generated.', 'address': '3G983JSIM ...'}
>>>
>>> Wallets.balances() # List Balances.
[{"Currency":"BTC","Deposited": 1 ,"Available": 1, "Unconfirmed": 5}]
>>>
>>> Wallets.transactions('BTC', type='transactions', pageindex=1, pagesize=50) # List History Transactions.
{'TotalElements': 50, 'Result': [{...} ...] ...}
>>>
>>> Wallets.withdraw('BBP', 'BPHoq ...', amount='2') # Withdraw
{'error': False, 'message': '', ...}
>>>
```
